Summary: Modern asynchronous API to the DNS
Name: getdns
Version: 1.3.0
Release: 3%{?dist}
License: BSD
Url: http://www.getdnsapi.net
Source: http://www.getdnsapi.net/dist/%{name}-%{version}.tar.gz
Group: System Environment/Libraries
BuildRequires: libidn2-devel unbound-devel doxygen libevent-devel
BuildRequires: pkgconfig openssl-devel libyaml-devel
Provides: stubby

Source2: tmpfiles-stubby.conf
Source3: stubby.service
Patch1: getdns-1.3.0-idn2.patch

%description
getdns is a modern asynchronous DNS API. It implements DNS entry points
from a design developed and vetted by application developers, in an API
specification edited by Paul Hoffman. With the development of this API,
we intend to offer application developers a modernized and flexible way
to access DNS security (DNSSEC) and other powerful new DNS features; a
particular hope is to inspire application developers towards innovative
security solutions in their applications.

%package devel
Summary: Development package that includes the header files
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
The devel package contains the getdns library and the include files and
some example C code.

%prep
%setup -q
%patch1 -p1

%build
%configure --disable-rpath --disable-static --with-libevent \
  --with-libidn2 --with-libunbound --with-stubby \
  --with-trust-anchor=%{_sharedstatedir}/unbound/root.anchor

make %{?_smp_mflags}
make %{?_smp_mflags} getdns_query

%check
# make test needs a network connection - so disabled per default
#make test

%install
make DESTDIR=%{buildroot} INSTALL="%{__install} -p" install
make DESTDIR=%{buildroot} INSTALL="%{__install} -p" install install-getdns_query

mkdir -p %{buildroot}%{_tmpfilesdir}
install %{SOURCE2} %{buildroot}%{_tmpfilesdir}/stubby.conf

mkdir -p %{buildroot}%{_unitdir}
install %{SOURCE3} %{buildroot}%{_unitdir}/stubby.service

rm -rf %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_docdir}/%{name}

%files
%{_libdir}/libgetdns*so.*
%{_bindir}/getdns_query
%{_bindir}/stubby
%dir %attr(0755,root,root) %{_sysconfdir}/stubby
%config(noreplace) %{_sysconfdir}/stubby/stubby.yml
%attr(0644,root,root) %{_unitdir}/stubby.service
%attr(0644,root,root) %{_tmpfilesdir}/stubby.conf
%doc README.md NEWS AUTHORS ChangeLog
%license LICENSE

%files devel
%{_libdir}/libgetdns*.so
%{_includedir}/getdns/
%{_libdir}/pkgconfig/*.pc
%{_mandir}/*/*.3*
%doc spec

%pre
getent group stubby >/dev/null || groupadd -r stubby
getent passwd stubby >/dev/null || \
useradd -r -g stubby -d %{_sysconfdir}/stubby -s /sbin/nologin \
    -c "stubby DNS daemon account" stubby
# If this makes you cry, read these and propose something better
# https://fedoraproject.org/wiki/Packaging:Tmpfiles.d
# https://github.com/getdnsapi/stubby/issues/62
install -d -g stubby -m 0750 %{_rundir}/stubby
exit 0

%post
/sbin/ldconfig
%systemd_post stubby.service

%preun
%systemd_preun stubby.service

%postun
/sbin/ldconfig
%systemd_postun_with_restart stubby.service

%changelog
* Wed Jan 10 2018 Paul Wouters <pwouters@redhat.com> - 1.3.0-3
- Minor fixup for previous patch
- Add Provides: for stubby

* Fri Jan 05 2018 Paul Wouters <pwouters@redhat.com> - 1.3.0-2
- Resolves: 1449127 getdns: switch to libidn2

* Tue Jan 02 2018 Paul Wouters <pwouters@redhat.com> - 1.3.0-1
- Updated to 1.3.0
- Move stubby from -devel to main package
- Add stubby as systemd service

* Fri Nov 17 2017 Paul Wouters <pwouters@redhat.com> - 1.2.1-1
- Updated to 1.2.1

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Jan 24 2017 Paul Wouters <pwouters@redhat.com> - 1.0.0-1
- Updated to 1.0.0

* Thu Sep 22 2016 Paul Wouters <pwouters@redhat.com> - 1.0.0-0.1.b2
- Updated to 1.0.0b2
- Moved getdns_query from devel to core package
- No longer require ldns

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jan 30 2016 Paul Wouters <pwouters@redhat.com> - 0.9.0-1
- Updated to 0.9.0
- Support pkgconfig

* Thu Nov 19 2015 Paul Wouters <pwouters@redhat.com> - 0.5.1-1
- Updated to 0.5.1

* Fri Sep 04 2015 Paul Wouters <pwouters@redhat.com> - 0.3.2-2
- Workaround for broken --with-getdns_query option
- Adds the getdns_query tool

* Fri Sep 04 2015 Paul Wouters <pwouters@redhat.com> - 0.3.2-1
- Updated to 0.3.2 with bugfix for fallback handling of stateful transports

* Sun Aug 23 2015 Paul Wouters <pwouters@redhat.com> - 0.3.1-1
- Updated to 0.3.1 Fix repeating rdata fields

* Fri Jul 17 2015 Paul Wouters <pwouters@redhat.com> - 0.3.0-1
- updated to 0.3.0 with bugfixes DNS parameter updates and API update

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 25 2015 Paul Wouters <pwouters@redhat.com> - 0.2.0-1
- Updated to 0.2.0 which includes full DNS over TLS support
- Updated spurious execute bit fixes
- Added explicit --with-* lines to make dependancies clear

* Mon Jan 19 2015 Paul Wouters <pwouters@redhat.com> - 0.1.6-1
- Updated to 0.1.6 with minor bugfixes
- Remove spurious execute bits from some *.[ch] files

* Fri Oct 31 2014 Paul Wouters <pwouters@redhat.com> - 0.1.5-1
- Updated to 0.1.5 with bugfixes and persistent TCP connections
- Example code moved into spec/

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jul 02 2014 Paul Wouters <pwouters@redhat.com> - 0.1.3-1
- Updated to 0.1.3

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu May 22 2014 Paul Wouters <pwouters@redhat.com> - 0.1.1-2
- Build with libevent support

* Wed Mar 26 2014 Paul Wouters <pwouters@redhat.com> - 0.1.1-1
- Updated to 0.1.1

* Fri Mar 21 2014 Paul Wouters <pwouters@redhat.com> - 0.1.0-2
- Remove cleaning in install
- Simplify files section and use macro instead of /var/lib

* Thu Feb 27 2014 Paul Wouters <pwouters@redhat.com> - 0.1.0-1
- Initial package
